==> javautils-sparkserver-0.0.6-sources.jar: tecgraf/javautils/sparkserver/standard/JuEndpoint.java <==
package tecgraf.javautils.sparkserver.standard;

import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import tecgraf.javautils.sparkserver.core.JuIController;
import tecgraf.javautils.sparkserver.core.JuIEndpoint;
import tecgraf.javautils.sparkserver.core.JuIFunction;
import tecgraf.javautils.sparkserver.core.JuIPathParameter;
import tecgraf.javautils.sparkserver.core.JuIQueryParameter;
import tecgraf.javautils.sparkserver.utils.JuStringUtilities;

public class JuEndpoint implements JuIEndpoint {

  final public JuVerb verb;
  final public String path;
  final public JuRoute route;

  private String name;
  private String description;

  private Set<JuIPathParameter> pathParameters = new HashSet<>();
  private Set<JuIQueryParameter> queryParameters = new HashSet<>();

  public <T> JuEndpoint(JuVerb verb, String path, JuIFunction<T> function, Class<T> responseClass) {
    this(verb, path, new JuRoute(function, responseClass));
  }

  public <T> JuEndpoint(JuVerb verb, String path, JuRoute<T> route) {
    if (verb == null) {
      throw new IllegalArgumentException("null verb not allowed!");
    }
    if (path == null) {
      throw new IllegalArgumentException("null path not allowed!");
    }
    if (route == null) {
      throw new IllegalArgumentException("null route not allowed!");
    }
    this.verb = verb;
    this.path = path;
    this.route = route;
  }

  @Override
  public JuVerb getVerb() {
    return verb;
  }

  @Override
  public String getPath() {
    return path;
  }

  @Override
  public JuRoute getRoute() {
    return route;
  }

  @Override
  public String getName() {
    return (name == null ? String.format("%d", System.identityHashCode(this)) : name.trim());
  }

  @Override
  public String getDescription() {
    return (description == null ? "" : description.trim());
  }

  @Override
  public JuIEndpoint setName(String name) {
    this.name = name;
    return this;
  }

  @Override
  public JuIEndpoint setDescription(String description) {
    this.description = description;
    return this;
  }

  @Override
  public List<String> findPathParameters() {
    String pth = getPath();
    final List<String> allMatches = JuStringUtilities.getAllMatches(pth, ":(\\w+)");
    return allMatches.stream().map(p -> p.substring(1)).collect(Collectors.toList());
  }

  @Override
  public JuIPathParameter addPathParameter(String name) {
    final boolean notFound = findPathParameters().stream().filter(pp -> pp.equals(name)).findAny().isEmpty();
    if (notFound) {
      throw new IllegalArgumentException("parameter not found" + name);
    }
    final JuPathParameter parameter = new JuPathParameter(name);
    this.pathParameters.add(parameter);
    return parameter;
  }

  @Override
  public JuIQueryParameter addQueryParameter(String name) {
    final JuQueryParameter parameter = new JuQueryParameter(name);
    this.queryParameters.add(parameter);
    return parameter;
  }

  @Override
  public Set<JuIPathParameter> getPathParameters() {
    return this.pathParameters;
  }

  @Override
  public Set<JuIQueryParameter> getQueryParameters() {
    return this.queryParameters;
  }

  public String toString() {
    return getVerb() + "::" + getPath();
  }

}

==> javautils-sparkserver-0.1.0-sources.jar: tecgraf/javautils/sparkserver/standard/JuEndpoint.java <==
package tecgraf.javautils.sparkserver.standard;

import java.util.Collection;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import tecgraf.javautils.sparkserver.core.JuIController;
import tecgraf.javautils.sparkserver.core.JuIEndpoint;
import tecgraf.javautils.sparkserver.core.JuIFunction;
import tecgraf.javautils.sparkserver.core.JuIPathParameter;
import tecgraf.javautils.sparkserver.core.JuIQueryParameter;
import tecgraf.javautils.sparkserver.core.JuIResponse;
import tecgraf.javautils.sparkserver.utils.JuStringUtilities;

public class JuEndpoint implements JuIEndpoint {

  final public JuVerb verb;
  final public String path;
  final public JuRoute route;

  private String name;
  private String description;

  private Set<JuIPathParameter> pathParameters = new HashSet<>();
  private Set<JuIQueryParameter> queryParameters = new HashSet<>();
  private HashMap<Integer, JuIResponse> responses = new HashMap<>();

  public <T> JuEndpoint(JuVerb verb, String path, JuIFunction<T> function, Class<T> responseClass) {
    this(verb, path, new JuRoute(function, responseClass));
  }

  public <T> JuEndpoint(JuVerb verb, String path, JuRoute<T> route) {
    if (verb == null) {
      throw new IllegalArgumentException("null verb not allowed!");
    }
    if (path == null) {
      throw new IllegalArgumentException("null path not allowed!");
    }
    if (route == null) {
      throw new IllegalArgumentException("null route not allowed!");
    }
    this.verb = verb;
    this.path = path;
    this.route = route;
  }

  @Override
  public JuVerb getVerb() {
    return verb;
  }

  @Override
  public String getPath() {
    return path;
  }

  @Override
  public JuRoute getRoute() {
    return route;
  }

  @Override
  public String getName() {
    return (name == null ? String.format("OP_%d", System.identityHashCode(this)) : name.trim());
  }

  @Override
  public String getDescription() {
    return (description == null ? "" : description.trim());
  }

  @Override
  public JuIEndpoint setName(String name) {
    this.name = name;
    return this;
  }

  @Override
  public JuIEndpoint setDescription(String description) {
    this.description = description;
    return this;
  }

  @Override
  public List<String> findPathParameters() {
    final String pth = getPath();
    final List<String> allMatches = JuStringUtilities.getAllMatches(pth, ":(\\w+)");
    return allMatches.stream().map(p -> p.substring(1)).collect(Collectors.toList());
  }

  @Override
  public JuIPathParameter addPathParameter(String name) {
    final boolean notFound = findPathParameters().stream().filter(pp -> pp.equals(name)).findAny().isEmpty();
    if (notFound) {
      throw new IllegalArgumentException("parameter not found" + name);
    }
    final JuPathParameter parameter = new JuPathParameter(name);
    this.pathParameters.add(parameter);
    return parameter;
  }

  @Override
  public JuIQueryParameter addQueryParameter(String name) {
    final JuQueryParameter parameter = new JuQueryParameter(name);
    this.queryParameters.add(parameter);
    return parameter;
  }

  @Override
  public JuIResponse addResponse(int code) {
    final JuResponse parameter = new JuResponse(code);
    this.responses.put(code, parameter);
    return parameter;
  }

  @Override
  public Set<JuIPathParameter> getPathParameters() {
    return this.pathParameters;
  }

  @Override
  public Set<JuIQueryParameter> getQueryParameters() {
    return this.queryParameters;
  }
  @Override
  public Collection<JuIResponse> getResponses() {
    if (responses.isEmpty()) {
      addResponse(200).setDescription("OK");
    }
    return this.responses.values();
  }

  public String toString() {
    return getVerb() + "::" + getPath();
  }

}
